@@ -11,5 +11,5 @@ class Action(Enum):
     RENAME = auto()
     DELETE = auto()
     RESET = auto()
-    RESET_REC = auto()
     MOVE = auto()
+    ADD_TAG = auto()
