@@ -1,3 +1,5 @@
+from datetime import datetime, timedelta
+
 from rich.align import Align
 from rich.console import RenderableType
 from rich.panel import Panel
@@ -5,7 +7,7 @@ from textual.reactive import Reactive
 from textual.widget import Widget
 
 from ..config import config
-from ..stopwatch import Stopwatch
+from ..stopwatch import Stopwatch, sec_to_str
 
 
 class Timer(Widget, can_focus=False):
@@ -14,34 +16,51 @@ class Timer(Widget, can_focus=False):
 
     def __init__(self, name: str | None = "Timer") -> None:
         super().__init__(name=name)
-        self.timer = Stopwatch()
+        self.stopwatch = Stopwatch()
 
     async def on_mount(self):
         self.set_interval(0.5, self.refresh)
 
     @property
-    def time(self) -> int:
-        return self.timer.get_elapsed_time()
+    def elapsed_time(self) -> timedelta:
+        return self.stopwatch.elapsed_time
+
+    def get_elapsed_time_str(self) -> str:
+        """returns formatted elapsed time [%H:]%M:%S"""
+        return sec_to_str(self.stopwatch.elapsed_time.seconds)
 
     @property
-    def time_str(self) -> str:
-        return self.timer.get_elapsed_time_str()
+    def saved_time(self) -> timedelta:
+        return self.stopwatch.saved_time
+
+    @property
+    def start_time(self) -> datetime:
+        return self.stopwatch.start_time
+
+    @property
+    def end_time(self) -> datetime:
+        return self.stopwatch.start_time + timedelta(
+            seconds=self.stopwatch.saved_time.seconds
+        )
 
     @property
     def working(self) -> bool:
         return self._working
 
-    def switch_timer(self):
-        self.timer.switch()
+    def start(self) -> None:
+        self.stopwatch.start()
 
-    def restart_timer(self):
-        self.timer.restart()
+    def stop(self) -> None:
+        self.stopwatch.stop()
+
+    def restart(self):
+        self.stopwatch.restart()
 
     def render(self) -> RenderableType:
-        self._working = self.timer.on
+        self._working = self.stopwatch.on
         self.panel = Panel(
             Align.center(
-                self.time_str,
+                self.get_elapsed_time_str(),
                 vertical="middle",
                 style=config.styles["TIMER_TEXT"],
             ),
